# Sage version information for Python scripts
# This file is auto-generated by the sage-update-version script, do not edit!
version = '10.1.rc0'
date = '2023-08-13'
banner = 'SageMath version 10.1.rc0, Release Date: 2023-08-13'
